# Django Browsable Router

[![Coverage Status](https://coveralls.io/repos/github/MrThearMan/django-browsable-router/badge.svg?branch=main)](https://coveralls.io/github/MrThearMan/django-browsable-router?branch=main)
[![GitHub Workflow Status](https://img.shields.io/github/workflow/status/MrThearMan/django-browsable-router/Tests)](https://github.com/MrThearMan/django-browsable-router/actions/workflows/main.yml)
[![PyPI](https://img.shields.io/pypi/v/django-browsable-router)](https://pypi.org/project/django-browsable-router)
[![GitHub](https://img.shields.io/github/license/MrThearMan/django-browsable-router)](https://github.com/MrThearMan/django-browsable-router/blob/main/LICENSE)
[![GitHub last commit](https://img.shields.io/github/last-commit/MrThearMan/django-browsable-router)](https://github.com/MrThearMan/django-browsable-router/commits/main)
[![GitHub issues](https://img.shields.io/github/issues-raw/MrThearMan/django-browsable-router)](https://github.com/MrThearMan/django-browsable-router/issues)

```shell
pip install django-browsable-router
```
---

**Documentation**: [https://mrthearman.github.io/django-browsable-router/](https://mrthearman.github.io/django-browsable-router/)

**Source Code**: [https://github.com/MrThearMan/django-browsable-router](https://github.com/MrThearMan/django-browsable-router)

---
